@@ -2,7 +2,7 @@
 
 import logging
 
-from .const import UpbCommand
+from .const import MINIMUM_BLINK_RATE, UpbCommand
 from .elements import Addr, Element, Elements
 from .message import (
     encode_blink,
@@ -40,13 +40,14 @@ class UpbDevice(Element):
         self._addr = addr
         self.status = None
         self.version = None
+        self.manufacturer = None
         self.product = None
         self.kind = None
         self.dimmable = None
 
     def _level(self, brightness, rate, encode_fn):
-        if not self.dimmable:
-            brightness = 0 if brightness < 50 else 100
+        if not self.dimmable and brightness > 0:
+            brightness = 100
         brightness, rate = check_dim_params(
             brightness, rate, self._pim.flags.get("use_raw_rate")
         )
@@ -75,8 +76,10 @@ class UpbDevice(Element):
 
     def blink(self, rate=-1):
         """(Helper) Blink a device."""
-        if rate < 30 and not self._pim.flags.get("unlimited_blink_rate"):
-            rate = 30
+        if rate < MINIMUM_BLINK_RATE and not self._pim.flags.get(
+            "unlimited_blink_rate"
+        ):
+            rate = MINIMUM_BLINK_RATE  # Force 1/3 of second blink rate
         self._pim.send(encode_blink(self._addr, rate), False)
         if self._pim.flags.get("report_state"):
             self._pim.send(encode_report_state(self._addr))
